DioFeature class
Constructors
DioFeature ({required Dio dio , int maxRequests = 1000 })
Methods
addListener (VoidCallback listener )
→ void
Register a closure to be called when the object changes.
inherited
build (BuildContext context )
→ Widget
override
clear ()
→ void
dispose ()
→ void
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
init (IADState state )
→ void
override
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners ()
→ void
Call all the registered listeners.
inherited
onError (DioException err , ErrorInterceptorHandler handler )
→ void
Called when an exception was occurred during the request.
onRequest (RequestOptions options , RequestInterceptorHandler handler )
→ void
Called when the request is about to be sent.
onResponse (Response response , ResponseInterceptorHandler handler )
→ void
Called when the response is about to be resolved.
removeListener (VoidCallback listener )
→ void
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
toString ()
→ String
A string representation of this object.
inherited